pub struct FinderFlags(/* private fields */);Expand description
Flags from the file information record used by Finder to manage files.
Adopted from Macintosh Toolbox Essentials, 7-47
use macintosh_utils::FinderFlags;
let flags = FinderFlags::from_bits(0x500).unwrap();
assert!(flags.contains(FinderFlags::CUSTOMICON));
assert!(flags.contains(FinderFlags::INITED));
assert!(!flags.contains(FinderFlags::INVISIBLE));Implementations
Sourceimpl FinderFlags
impl FinderFlags
Sourcepub const ALIAS: Self
pub const ALIAS: Self
For a file, this bit indicates that the file is an alias file. For directories, this bit is reserved—in which case, set to 0.
Sourcepub const INVISIBLE: Self
pub const INVISIBLE: Self
The file or directory is invisible from the Finder and from the Standard File Package dialog boxes.
Sourcepub const BUNDLE: Self
pub const BUNDLE: Self
For a file, this bit indicates that the file contains a bundle resource. For directories, this bit is reserved – in which case, set to 0.
Sourcepub const NAMELOCKED: Self
pub const NAMELOCKED: Self
The file or directory can’t be renamed from the Finder, and the icon cannot be changed.
Sourcepub const STATIONERY: Self
pub const STATIONERY: Self
This flag specifies that a file is a stationery pad and should be treated as a document template rather than a document itself
Sourcepub const CUSTOMICON: Self
pub const CUSTOMICON: Self
The file or directory contains a customized icon
Sourcepub const INITED: Self
pub const INITED: Self
The Finder has recorded information from the file’s bundle resource into the desktop database and given the file or folder a position on the desktop.
Sourcepub const NOINIT: Self
pub const NOINIT: Self
The file contains no ‘INIT’ resources; set to 0. Reserved for directories; set to 0.
Sourcepub const SHARED: Self
pub const SHARED: Self
The file is an application that can be executed by multiple users simultaneously. Defined only for applications; otherwise, set to 0.
Sourcepub const SWITCH_LAUNCH: Self
pub const SWITCH_LAUNCH: Self
Unused and reserved in System 7; set to 0.
Sourcepub const COLOR_RESERVED: Self
pub const COLOR_RESERVED: Self
Unused and reserved in System 7; set to 0.
Sourcepub const ON_DESKTOP: Self
pub const ON_DESKTOP: Self
Unused and reserved in System 7; set to 0.
Sourceimpl FinderFlags
impl FinderFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FinderFlags
impl FinderFlags
Sourcepub const fn iter(&self) -> Iter<FinderFlags>
pub const fn iter(&self) -> Iter<FinderFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FinderFlags>
pub const fn iter_names(&self) -> IterNames<FinderFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.