macintosh-utils
A collection of utilities to simplify working with classic macintosh files and programs.
Re-exports
Modules
- type_
code - Constants for well-known file type codes
Macros
Structs
- Finder
Flags - Flags from the file information record used by Finder to manage files.
- FourCC
- A four-character code
- Pascal
String - Common string variant where one-byte denotes the length of the string followed by that many mac-roman encoded characters
- Point
- Point in 2D space, serializable
Enums
- Fork
- Identifies either of the two forks that can be used to store data on classic Macintosh file systems
Functions
- date
- Helper to a allow binrw to read macintosh dates more easily
- decode_
string - Helper to a allow binrw to read mac-roman strings more easily
- decode_
string_ from_ slice - Helper to a allow binrw to read mac-roman strings more easily
- string
- Helper to a allow binrw to read pscal strings more easily